.. Copyright 2013 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.sqlalchemysupport
------------------------------

.. automodule:: reahl.sqlalchemysupport
   :members: Session, Base, metadata


SqlAlchemyControl
"""""""""""""""""

.. autoclass:: SqlAlchemyControl
   :members:


QueryAsSequence
"""""""""""""""

.. autoclass:: QueryAsSequence
   :members:


PersistedField
""""""""""""""

.. autoclass:: PersistedField
   :members: